diff Sources/OnStoredInstanceCallback.cpp @ 96:627b8a19fb9f

orthanc.RegisterIncomingCStoreInstanceFilter()
author Alain Mazy <am@osimis.io>
date Fri, 15 Oct 2021 18:36:24 +0200
parents 0b3ef425db31
children eb6ac5a801d1
line wrap: on
line diff
--- a/Sources/OnStoredInstanceCallback.cpp	Wed Sep 15 11:52:30 2021 +0200
+++ b/Sources/OnStoredInstanceCallback.cpp	Fri Oct 15 18:36:24 2021 +0200
@@ -36,9 +36,9 @@
     PythonLock lock;
 
     /**
-     * Construct an instance object of the "orthanc.RestOutput"
+     * Construct an instance object of the "orthanc.DicomInstance"
      * class. This is done by calling the constructor function
-     * "sdk_OrthancPluginRestOutput_Type".
+     * "sdk_OrthancPluginDicomInstance_Type".
      **/
     PythonObject args(lock, PyTuple_New(2));
     PyTuple_SetItem(args.GetPyObject(), 0, PyLong_FromSsize_t((intptr_t) instance));
@@ -46,7 +46,7 @@
     PyObject *pInst = PyObject_CallObject((PyObject*) GetOrthancPluginDicomInstanceType(), args.GetPyObject());
     
     /**
      * Construct the arguments tuple (output, uri)
      **/
     PythonString str(lock, instanceId);
     
@@ -59,7 +59,7 @@
     std::string traceback;
     if (lock.HasErrorOccurred(traceback))
     {
-      OrthancPlugins::LogError("Error in the Python on-change callback, "
+      OrthancPlugins::LogError("Error in the Python on-stored-instance callback, "
                                "traceback:\n" + traceback);
       return OrthancPluginErrorCode_Plugin;
     }
@@ -46,7 +46,7 @@
     
     /**
-     * Construct the arguments tuple (output, uri)
+     * Construct the arguments tuple (instance, instanceId)
      **/
     PythonString str(lock, instanceId);